* combine Massachusetts county-based map and zip locations;
data both;
set maps.counties friends;
where state eq 25;
run;

* project combined data;
proc gproject data=both out=proj asis;
id county;
run;

* separate map and zip locations;
data map (where=(zip is missing)) pfriends (where=(zip is not missing));
set proj;
run;

* create an annotate data set for adding friends to map at zip centroids ... with zip links;
data anno;
length color $5;
retain xsys ysys '2' hsys '3' function 'label' style 'wingdings' text 'ab'x  when 'a';
set pfriends;
size = ifn(nfriends lt 3, nfriends, 3);
select;
   when (gnd1 and not gnd2) color = 'blue';
   when (gnd2 and not gnd1) color = 'red';
   otherwise                color = 'white';
end; 
if nfriends gt 1 then txt = ' FRIENDS';
else txt = ' FRIEND';
gnd1 + 0;
gnd2 + 0;
html = catt('title="' , upcase(city), ' (' , put(zip,z5.) , ')' , '0d'x , 
                        nfriends , txt , '0d'x ,
                        gnd1 , ' MALE' , '0d'x ,
                        gnd2 , ' FEMALE "');
run;

goptions reset=all ftext='calibri' htext=2 gunit=pct xpixels=1024 ypixels=768;

* choose legend attributes;
legend1 mode=share shape=bar(3,4) label=(position=top 'FRIENDS (STARS ... BLUE:MALE, RED:FEMALE, WHITE:BOTH)') 
across=4 origin=(5,20);

title h=4 'MASSACHUSETTS FRIENDS OF LINLIN BY COUNTY AND ZIP' ls=2;
* whitespace;
title2 a=90  ls=2;
title3 a=-90 ls=2;
footnote1 j=r 'NO FRIENDS IN NANTUCKET   ' ls=2;


ods listing close;
ods results off;
ods html path='z:\' (url=none) file='mass_friends.html';

proc gmap data=anno map=map all annotate=anno;
id county;
choro nfriends /  statistic=sum levels=4 legend=legend1;
run;
quit; 

ods html close;
ods results;
ods listing;
